# libpythonpro

Módulo para exemplificar a construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto.

Link para o curso [Python Pro](https://pythonpro.com.br)

[![Build Status](https://app.travis-ci.com/olv-leo/libpythonpro.svg?branch=main)](https://app.travis-ci.com/olv-leo/libpythonpro)
[![Updates](https://pyup.io/repos/github/olv-leo/libpythonpro/shield.svg)](https://pyup.io/repos/github/olv-leo/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/olv-leo/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/olv-leo/libpythonpro/)

Para fazer a instalação (no Windowns):

```console
python -m venv .venv
.venv\Scripts\activate
pip install -r requirements-dev.txt

```

Para conferir qualidade do código:

```console
flake8

```

Tópicos a serem abordados:

1. Git
2. Virtualenv
3. Pip
